<?php
/**
 * Moral functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Moral
 */

if ( ! function_exists( 'moral_magazine_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function moral_magazine_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Moral, use a find and replace
		 * to change 'moral-magazine' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'moral-magazine' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'register_block_pattern' );
		
		add_theme_support( 'register_block_style' );

		add_theme_support( 'responsive-embeds' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		
		add_image_size( 'moral-magazine-home-blog', 400, 300, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'moral-magazine' ),
			'secondary' => esc_html__( 'Secondary', 'moral-magazine' ),
			'social' => esc_html__( 'Social', 'moral-magazine' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'moral_magazine_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		add_theme_support( 'custom-header', array(
		        'default-image'      => '%s/assets/img/header-image.jpg',
		        'default-text-color' => '000',
		        'width'              => 1920,
		        'height'             => 1080,
		        'flex-width'         => true,
		        'flex-height'        => true,
		    ) );
		 // Register default headers.
		register_default_headers( array(
			'default-banner' => array(
				'url'           => '%s/assets/img/header-image.jpg',
				'thumbnail_url' => '%s/assets/img/header-image.jpg',
				'description'   => esc_html_x( 'Default Banner', 'Header image description', 'moral-magazine' ),
			),

		) );

				/**
		 * WooCommerce setup function.
		 *
		 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
		 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
		 *
		 * @return void
		 */
		if ( class_exists( 'WooCommerce' ) ) {
	    	global $woocommerce;
	
	    	if( version_compare( $woocommerce->version, '3.0.0', ">=" ) ) {
	    		add_theme_support('woocommerce');
	      		add_theme_support( 'wc-product-gallery-zoom' );
				add_theme_support( 'wc-product-gallery-lightbox' );
				add_theme_support( 'wc-product-gallery-slider' );
			}
	  	}

		// Add theme support for selective refresh for widgets.
		// add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

    	/*
    	 * This theme styles the visual editor to resemble the theme style,
    	 * specifically font, colors, and column width.
     	 */
    	add_editor_style( array( 'assets/css/editor-style.css', moral_magazine_fonts_url() ) );

    	// Gutenberg support
		add_theme_support( 'editor-color-palette', array(
	       	array(
				'name' => esc_html__( 'Blue', 'moral-magazine' ),
				'slug' => 'blue',
				'color' => '#2c7dfa',
	       	),
	       	array(
	           	'name' => esc_html__( 'Green', 'moral-magazine' ),
	           	'slug' => 'green',
	           	'color' => '#07d79c',
	       	),
	       	array(
	           	'name' => esc_html__( 'Orange', 'moral-magazine' ),
	           	'slug' => 'orange',
	           	'color' => '#ff8737',
	       	),
	       	array(
	           	'name' => esc_html__( 'Black', 'moral-magazine' ),
	           	'slug' => 'black',
	           	'color' => '#2f3633',
	       	),
	       	array(
	           	'name' => esc_html__( 'Grey', 'moral-magazine' ),
	           	'slug' => 'grey',
	           	'color' => '#82868b',
	       	),
	   	));

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'moral-magazine' ),
		       	'shortName' => esc_html__( 'S', 'moral-magazine' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'moral-magazine' ),
		       	'shortName' => esc_html__( 'M', 'moral-magazine' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'moral-magazine' ),
		       	'shortName' => esc_html__( 'L', 'moral-magazine' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'moral-magazine' ),
		       	'shortName' => esc_html__( 'XL', 'moral-magazine' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
	}
endif;
add_action( 'after_setup_theme', 'moral_magazine_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function moral_magazine_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'moral_magazine_content_width', 900 );
}
add_action( 'after_setup_theme', 'moral_magazine_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function moral_magazine_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'moral-magazine' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'moral-magazine' ),
		'id'            => 'blog-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Hero Banner Sidebar', 'moral-magazine' ),
		'id'            => 'hero-banner-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Featured News Left Sidebar', 'moral-magazine' ),
		'id'            => 'featured-news-left-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Featured News Right Sidebar', 'moral-magazine' ),
		'id'            => 'featured-news-right-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Main Post Left Sidebar', 'moral-magazine' ),
		'id'            => 'main-post-left-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Main Post Right Sidebar', 'moral-magazine' ),
		'id'            => 'main-post-right-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );


	for ( $i=1; $i <= 4; $i++ ) { 
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area ', 'moral-magazine' )  . $i,
			'id'            => 'footer-' . $i,
			'description'   => esc_html__( 'Add widgets here.', 'moral-magazine' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
}
add_action( 'widgets_init', 'moral_magazine_widgets_init' );

/**
 * Register custom fonts.
 */
function moral_magazine_fonts_url() {
	$fonts_url = '';

	$font_families = array();
	
	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Montserrat, translate this to 'off'. Do not translate
	 * into your own language.
	 */

	$playfair_display = _x( 'on', 'Playfair Display font: on or off', 'moral-magazine' );

	if ( 'off' !== $playfair_display ) {
		$font_families[] = 'Playfair Display:400,500,600';
	}

	$lato = _x( 'on', 'Lato Display font: on or off', 'moral-magazine' );

	if ( 'off' !== $lato ) {
		$font_families[] = 'Lato Display:300,400,700';
	}

	if(!empty( get_theme_mod('moral_magazine_body_font_option') )){
		$body_font_family = explode( '-', get_theme_mod( 'moral_magazine_body_font_option'  ) );
	    $body_font_family = implode( ' ', array_map( 'ucfirst', $body_font_family ) );

		$font_families[] =  $body_font_family.':400,700';
	}

	if(!empty( get_theme_mod('moral_magazine_h1_h6_font_option') )){
		$h1_h6_font_family = explode( '-', get_theme_mod( 'moral_magazine_h1_h6_font_option'  ) );
	    $h1_h6_font_family = implode( ' ', array_map( 'ucfirst', $h1_h6_font_family ) );
	    
		$font_families[] = $h1_h6_font_family.':400,700';
	}

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);

	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function moral_magazine_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'moral-magazine-fonts', moral_magazine_fonts_url(), array(), null );
	
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', '', '4.7.0' );

	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/css/slick.css', '', '1.8.0' );

	wp_enqueue_style( 'slick-theme', get_template_directory_uri() . '/assets/css/slick-theme.css', '', '1.8.0' );

	// blocks
	wp_enqueue_style( 'moral-magazine-blocks', get_template_directory_uri() . '/assets/css/blocks.css' );

	wp_enqueue_style( 'moral-magazine-style', get_stylesheet_uri() );

	wp_enqueue_script( 'imagesloaded');

	wp_enqueue_script( 'packery-pkgd', get_template_directory_uri() . '/assets/js/packery.pkgd.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'sticky-sidebar', get_template_directory_uri() . '/assets/js/sticky-sidebar.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'slick-jquery', get_template_directory_uri() . '/assets/js/slick.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'moral-magazine-navigation', get_template_directory_uri() . '/assets/js/navigation.js' , array(), '20151215', true );

	wp_enqueue_script( 'moral-magazine-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'moral-magazine-custom', get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'moral_magazine_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since moral-magazine 1.0.0
 */
function moral_magazine_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'moral-magazine-block-editor-style', get_template_directory_uri( '/assets/css/editor-blocks.css' ) );
	// Add custom fonts.
	wp_enqueue_style( 'moral-magazine-fonts', moral_magazine_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'moral_magazine_block_editor_styles' );

/**
 * Custom template tags for this theme.
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_parent_theme_file_path( '/inc/template-functions.php' );

/**
 * Customizer additions.
 */
require get_parent_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

/**
 * Breadcrumb trail class.
 */
require get_parent_theme_file_path( '/inc/class-breadcrumb-trail.php' );

/**
 * Custom widget additions.
 */
require get_parent_theme_file_path( '/inc/widgets/widgets.php' );

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_parent_theme_file_path() . '/inc/jetpack.php';
}

/**
 * Metabox
 */
require get_parent_theme_file_path( '/inc/metabox.php' );


/**
 * TGMPA call
 */
require get_parent_theme_file_path( '/inc/tgmpa/call.php' );

require get_parent_theme_file_path( '/inc/custom-style.php' );


if ( class_exists( 'CatchThemesDemoImportPlugin' ) ) {
    /**
    * OCDI plugin demo importer compatibility.
    */
    require get_template_directory() . '/inc/demo-import.php';
}


/**
 * Enqueue admin css.
 * @return [type] [description]
 */
function moral_magazine_load_custom_wp_admin_style( $hook ) {
	if ( 'appearance_page_moral-magazine-welcome' != $hook ) {
        return;
    }
    wp_register_style( 'moral-magazine-admin', get_theme_file_uri( 'assets/css/moral-magazine-admin.css' ), false, '1.0.0' );
    wp_enqueue_style( 'moral-magazine-admin' );
}
add_action( 'admin_enqueue_scripts', 'moral_magazine_load_custom_wp_admin_style' );



/**
 *
 * Reset all setting to default.
 *
 */
function moral_magazine_reset_settings() {
    $reset_settings = get_theme_mod( 'moral_magazine_reset_settings', false );
    if ( $reset_settings ) {
        remove_theme_mods();
    }
}
add_action( 'customize_save_after', 'moral_magazine_reset_settings' );


if ( ! function_exists( 'moral_magazine_exclude_sticky_posts' ) ) {
    function moral_magazine_exclude_sticky_posts( $query ) {
        if ( ! is_admin() && $query->is_main_query() && $query->is_home() ) {
            $sticky_posts = get_option( 'sticky_posts' );  
            if ( ! empty( $sticky_posts ) ) {
            	$query->set('post__not_in', $sticky_posts );
            }
            $query->set('ignore_sticky_posts', true );
        }
    }
}
add_action( 'pre_get_posts', 'moral_magazine_exclude_sticky_posts' );


// Sections Style

$sorted_sections = array( 'breaking-news', 'hero-banner', 'featured-news', 'editorial', 'have-missed' );

foreach ( $sorted_sections as $sorted_section ) {
	require get_parent_theme_file_path( '/style/'.$sorted_section.'.php' );
}